@@ -2,6 +2,7 @@ from radboy.DB.db import *
 from radboy.FB.FormBuilder import FormBuilder
 from copy import deepcopy as copy
 from radboy.ExportUtility import *
+import radboy.HealthLog as HL
 def CountTo():
     fd={
         'Start':{
@@ -62,7 +63,7 @@ def CountTo():
                     elif do in [False,]:
                         continue
                 present=datetime.now()
-            print(final_msg)
+            print(f"{Fore.orange_red_1}Done!{Style.reset}",final_msg)
             rerun=Control(func=FormBuilderMkText,ptext="re-run from absolute start? [y/N]",helpText="yes or no",data="boolean")
             if rerun is None:
                 return
@@ -80,9 +81,10 @@ def CountTo():
             else:
                 useLast=True
                 continue
-
+            print(final_msg)
             break
-
+MOOD_STRING='''
+'''
 
 class OrderedAndRecieved(BASE,Template):
     '''
@@ -95,7 +97,7 @@ class OrderedAndRecieved(BASE,Template):
     Description=Column(String,default=None)
     oarid=Column(Integer,primary_key=True)
     dtoe=Column(DateTime,default=datetime.now())
-    
+
     order_dt=Column(DateTime,default=datetime.now())
     rx_dt=Column(DateTime,default=datetime.today()+timedelta(days=1))
 
@@ -130,9 +132,18 @@ class OrderedAndRecieved(BASE,Template):
     dairy_fluid_thrown=Column(Boolean,default=False)
     dairy_fluid_dropped=Column(Boolean,default=False)
     dairy_crated_fluids_thrown=Column(Boolean,default=False)
+    dairy_cmt=Column(String,default='')
 
+    was_frozen_assisted=Column(Boolean,default=False)
+    frozne_load_thrown=Column(Boolean,default=False)
+    frozne_load_dropped=Column(Boolean,default=False)
+    frozne_load_broken=Column(Boolean,default=False) 
+    frozen_old_load_broken=Column(Boolean,default=False)
+    frozen_old_load_broken=Column(Boolean,default=False)
+    frozen_old_load_cmt=Column(String,default='')
     sixteen_lb_ice_thrown=Column(Boolean,default=False)
     nine_lb_ice_thrown=Column(Boolean,default=False)
+    frozen_cmt=Column(String,default='')
 
     empty_pallets_exported=Column(Integer,default=0)
     crate_pallets_exported=Column(Integer,default=0)
@@ -166,6 +177,101 @@ class OrderedAndRecieved(BASE,Template):
     DT_to_lunch=Column(DateTime,default=None)
     DT_from_lunch=Column(DateTime,default=None)
     DT_punched_out=Column(DateTime,default=None)
+    DT_grocery_breakdown_finished=Column(DateTime,default=None)
+    DT_frozen_breakdown_finished=Column(DateTime,default=None)
+
+    clocked_in_early=Column(Boolean,default=False)
+    clocked_in_late=Column(Boolean,default=False)
+    clocked_out_early=Column(Boolean,default=False)
+    clocked_out_late=Column(Boolean,default=False)
+    lunch_out_early=Column(Boolean,default=False)
+    lunch_in_early=Column(Boolean,default=False)
+    lunch_out_late=Column(Boolean,default=False)
+    lunch_in_late=Column(Boolean,default=False)
+
+    assisted_deli=Column(Boolean,default=False)
+    assisted_deli_with=Column(String,default='')
+
+    rate_your_anger_0_to_10=Column(Integer,default=0)
+    rate_your_anxiety_0_to_10=Column(Integer,default=0)
+    rate_your_mood_0_to_10=Column(Integer,default=0)
+    rate_your_energy_0_to_10=Column(Integer,default=0)
+    rate_your_worriedness_0_to_10=Column(Integer,default=0)
+    personal_comment_related_to_rating=Column(String,default=MOOD_STRING)
+
+    was_receiving_assisted=Column(Boolean,default=False)
+    recieving_comments=Column(Text,default=None)
+    reciever_name=Column(String,default='')
+    reciever_present_by_dt=Column(DateTime,default=None)
+    was_there_a_reciever=Column(Boolean,default=False)
+
+    was_gm_assisted=Column(Boolean,default=False)
+    gm_comments=Column(Text,default=None)
+    gm_manager_name=Column(String,default='')
+    gm_manager_present_by_dt=Column(DateTime,default=None)
+    was_there_a_gm_manager=Column(Boolean,default=False)
+
+    was_liquor_assisted=Column(Boolean,default=False)
+    liquor_comments=Column(Text,default=None)
+    liquor_manager_name=Column(String,default='')
+    liquor_manager_present_by_dt=Column(DateTime,default=None)
+    was_there_a_liquor_manager=Column(Boolean,default=False)
+
+    was_grocery_assisted=Column(Boolean,default=False)
+    grocery_comments=Column(Text,default=None)
+    grocery_manager_name=Column(String,default='')
+    grocery_manager_present_by_dt=Column(DateTime,default=None)
+    was_there_a_grocery_manager=Column(Boolean,default=False)
+
+    was_dairy_assisted=Column(Boolean,default=False)
+    dairy_comments=Column(Text,default=None)
+    dairy_manager_name=Column(String,default='')
+    dairy_manager_present_by_dt=Column(DateTime,default=None)
+    was_there_a_dairy_manager=Column(Boolean,default=False)
+
+    was_meat_department_assisted=Column(Boolean,default=False)
+    meat_department_comments=Column(Text,default=None)
+    meat_department_manager_name=Column(String,default='')
+    meat_department_manager_present_by_dt=Column(DateTime,default=None)
+    was_there_a_meat_department_manager=Column(Boolean,default=False)
+
+    was_deli_assisted=Column(Boolean,default=False)
+    deli_comments=Column(Text,default=None)
+    deli_manager_name=Column(String,default='')
+    deli_manager_present_by_dt=Column(DateTime,default=None)
+    was_there_a_deli_manager=Column(Boolean,default=False)
+
+    was_bakery_assisted=Column(Boolean,default=False)
+    bakery_comments=Column(Text,default=None)
+    bakery_manager_name=Column(String,default='')
+    #Column(String,default=None)
+    bakery_manager_present_by_dt=Column(DateTime,default=None)
+    was_there_a_bakery_manager=Column(Boolean,default=False)
+
+    did_you_deliver_general_merchadise=Column(String,default=None)
+    did_you_break_down_general_merchandise=Column(String,default=None)
+    did_throw_general_merchandise=Column(String,default=None)
+    did_you_face_general_merchandise=Column(String,default=None)
+    did_you_face_endcaps_frontend_displays=Column(String,default=None)
+    did_you_deliver_tote_pallets=Column(String,default=None)
+    did_you_deliver_bread_stacks=Column(String,default=None)
+    did_you_deliver_red_totes_to_icc=Column(String,default=None)
+    did_deliver_warehouse39=Column(String,default=None)
+    did_you_deliver_kehe=Column(String,default=None)
+    did_you_throw_kehe=Column(String,default=None)
+    did_you_break_down_kehe=Column(String,default=None)
+    did_you_break_down_warehouse39=Column(String,default=None)
+    did_you_throw_warehouse39=Column(String,default=None)
+    did_deliver_bakery_items=Column(String,default=None)
+    did_you_deliver_meat_items=Column(String,default=None)
+    did_you_deliver_deli_items=Column(String,default=None)
+    did_you_deliver_starbucks_items=Column(String,default=None)
+    did_you_deliver_anything_to_file_maintenance=Column(String,default=None)
+    did_you_deliver_anything_to_the_front_end_or_customer_service=Column(String,default=None)
+    did_you_condense_beverage=Column(String,default=None)
+    did_you_deliver_anything_for_anyother_department_other_than_assigned=Column(String,default=None)
+    your_assigned_department=Column(String,default=None)
+
 
     comment=Column(String,default='')
     
@@ -180,7 +286,7 @@ except Exception as e:
     OrderedAndRecieved.metadata.create_all(ENGINE) 
  
 class OrderAndRxdUi():
-    def between_dates(self,paged=False,limit=False,short_display=False):
+    def between_dates(self,query):
         '''list everything between start and end
         paged=True -> page results and use menu to edit/delete/stop paging
         paged=False -> print all at once
@@ -188,9 +294,27 @@ class OrderAndRxdUi():
         limit=False -> everything is printed
         short_display=True -> display less information
         '''
-        with Session(ENGINE) as session:
-            start=None
-            end=None
+        start=Control(func=FormBuilderMkText,ptext="Start DateTime: ",helpText="starting datetime",data="datetime")
+        if start is None:
+            return
+        elif not isinstance(start,datetime):
+            return
+
+        end=Control(func=FormBuilderMkText,ptext="End DateTime: ",helpText="ending datetime",data="datetime")
+        if end is None:
+            return
+        elif not isinstance(end,datetime):
+            return
+        print(f""""
+{Fore.orange_red_1}Results are for dates between
+{Fore.light_green}Start: {start}
+{Fore.light_red}End: {end}
+{'-'*(os.get_terminal_size().columns-len(Style.reset))}{Style.reset}
+            """)
+        return orderQuery(query.filter(and_(
+            OrderedAndRecieved.dtoe >= start,
+            OrderedAndRecieved.dtoe <= end))
+        ,OrderedAndRecieved.dtoe,inverse=True)
 
     def fixtable(self):
         OrderedAndRecieved.__table__.drop(ENGINE)
@@ -214,7 +338,10 @@ class OrderAndRxdUi():
                         pass
                 else:
                     filte.append(getattr(OrderedAndRecieved,k)==src_dict[k])
-        return and_(*filte)
+        #uncomment these to troubleshoot
+        #print('x3',and_(*filte))
+        #print('x4')
+
 
     def OrderedAndRecieved_as(self,_exlcudes=[],as_=None,item=None):
         excludes=['oarid',]
@@ -256,14 +383,23 @@ class OrderAndRxdUi():
             raise Exception(f"Not a registered as_('{as_}')")
         if fields is not None:
             fd=FormBuilder(data=fields)
+            if fd is None:
+                print("User Cancelled! OrderedAndRecieved_as(self,_exlcudes=[],as_=None,item=None)")
+                return
             return fd,fields
 
     def search(self,selector=False,menu=False):
-        terms,z=self.OrderedAndRecieved_as(as_=None)
+        nantucket=self.OrderedAndRecieved_as(as_=None)
+        if nantucket is None:
+            print("User cancelled! search(self,selector=False,menu=False)")
+            return
+        terms,z=nantucket
         terms=self.filter(terms)
         def selectortext(results,page=False,self=self):
             def edit(i,self=self):
                 edits=self.OrderedAndRecieved_as(as_="from_item",item=i)
+                if edits is None:
+                    return
                 with Session(ENGINE) as session:
                     e=session.query(OrderedAndRecieved).filter(OrderedAndRecieved.oarid==i.oarid).first()
                     if e is not None:
@@ -284,7 +420,7 @@ class OrderAndRxdUi():
                     while not ready:
                         menu=Control(func=FormBuilderMkText,ptext="edit/e or r/rm/del/delete/dlt",helpText="edit or delete",data="string")
                         if menu is None:
-                            continue
+                            return
                         elif menu in ['d',]:
                             print(std_colorize(i,num,ct))
                             continue
@@ -299,28 +435,43 @@ class OrderAndRxdUi():
                             continue
                 
 
-        if terms is not None:
-            with Session(ENGINE) as session:
-                query=session.query(OrderedAndRecieved).filter(*terms)
-                query=orderQuery(query,OrderedAndRecieved.dtoe)
-                results=query.all()
-                ct=len(results)
-                plural=''
-                if ct > 1:
-                    plural="s"
-                print(f"{ct} result{plural}!")
-                if not selector:
-                    for num,i in enumerate(results):
-                        print(std_colorize(i,num,ct))
+        
+        with Session(ENGINE) as session:
+            query=session.query(OrderedAndRecieved)
+            if terms is not None:
+                query=query.filter(terms)
+            query=orderQuery(query,OrderedAndRecieved.dtoe)
+            between_dates=Control(func=FormBuilderMkText,ptext="Between dates? y/n",helpText="values between two dates",data="boolean")
+            if between_dates is None:
+                return None
+            if between_dates in ['d',False]:
+                pass
+            else:
+                query=self.between_dates(query)
 
-                if selector:
-                    #for returning a list of OrderedAndRecieved
-                    selectortext(resuls)
-                    pass
-                if menu:
-                    #for paged edit/delete of OrderedAndRecieved and returns None
-                    selectortext(results,page=True)
-                    pass
+            results=query.all()
+            ct=len(results)
+            plural=''
+            if ct > 1:
+                plural="s"
+            print(f"{ct} result{plural}!")
+            zebra=0
+                
+
+            if selector:
+                #for returning a list of OrderedAndRecieved
+                selectortext(resuls)
+                zebra+=1
+                pass
+            if menu:
+                #for paged edit/delete of OrderedAndRecieved and returns None
+                selectortext(results,page=True)
+                zebra+=1
+                pass
+
+            if not(zebra > 0):
+                for num,i in enumerate(results):
+                        print(std_colorize(i,num,ct))
 
 
     def __init__(self,*args,**kwargs):
@@ -354,6 +505,11 @@ class OrderAndRxdUi():
             'desc':'drop and recreate table',
             'exec':lambda self=self:self.fixtable()
         }
+        self.cmds[uuid1()]={
+            'cmds':generate_cmds(startcmd=['health','h',],endCmd=['log', 'l',]),
+            'desc':'healthlog',
+            'exec':lambda self=self:HL.HealthLog.HealthLogUi()
+        }
         self.cmds["ExportTables"]={
         'cmds':["export tables","xpttbl",],
         'desc':f'import/export selected tables to/from selected XLSX (Excel)/ODF',
@@ -376,7 +532,7 @@ class OrderAndRxdUi():
                 elif i in self.registry:
                     self.cmds[cmd]['cmds'].pop(self.cmds[cmd]['cmds'].index(i))
             htext.append(std_colorize(f"{self.cmds[cmd]['cmds']} - {self.cmds[cmd]['desc']}",xnum,ct))
-        htext=''.join(htext)
+        htext='\n'.join(htext)
         print(htext)
         while True:
             doWhat=Control(func=FormBuilderMkText,ptext=f"{self.__class__.__name__}:Do What what",helpText=htext,data="string")
@@ -410,6 +566,6 @@ class OrderAndRxdUi():
                 for k in fd:
                     setattr(t,k,fd[k])
                 session.commit()
-            session.refresh(t)
-        
-            print(t)
\ No newline at end of file
+                session.refresh(t)
+            
+                print(t)
\ No newline at end of file
