@@ -166,7 +166,7 @@ def FormBuilderMkText(text,data,passThru=[],PassThru=True,alternative_false=None
                     return 'd'
         elif data.lower() in ['decimal.decimal','dec.dec']:
             try:
-                value=Decimal(text).quantize(Decimal('0.0000'))
+                value=Decimal(text)
                 return value
             except Exception as e:
                 print(e)
